@@ -70,8 +70,8 @@ TelepathyKDEDConfig::TelepathyKDEDConfig(QWidget *parent, const QVariantList& ar
     resizer->addWidgetsFromLayout(ui->incomingFilesGroupBox->layout(), 0);
     resizer->addWidgetsFromLayout(ui->autoAwayGroupBox->layout(), 0);
     resizer->addWidgetsFromLayout(ui->nowPlayingGroupBox->layout(), 0);
-    resizer->addWidgetsFromLayout(ui->autoConnectGroupBox->layout(), 0);
-    resizer->addWidgetsFromLayout(ui->autoOfflineGroupBox->layout(), 0);
+    resizer->addWidgetsFromLayout(ui->presenceGroupBox->layout(), 0);
+
 
     //TODO enable this when it is supported by the approver
     ui->m_autoAcceptCheckBox->setHidden(true);
